/**
 * @brief A file containing implementation of classes for extracting, holding
 *   and manipulating the debugging information.
 *
 * A file containing implementation of classes for extracting, holding and
 *   manipulating the debugging information.
 *
 * @file      die.cpp
 * @author    Jan Fiedor (fiedorjan@centrum.cz)
 * @date      Created 2011-08-01
 * @date      Last Update 2012-05-24
 * @version   0.1.0.2
 */

#include "die.h"

#ifdef TARGET_LINUX
  #include "dwarf/dw_die.h"
#endif

/**
 * Constructs a DebugInfo object.
 */
DebugInfo::DebugInfo()
{
}

/**
 * Destroys a DebugInfo object.
 */
DebugInfo::~DebugInfo()
{
}

/**
 * Constructs an ExtractionError object.
 *
 * @param message A message describing an error.
 */
ExtractionError::ExtractionError(std::string message) throw()
  : m_message(message)
{
}

/**
 * Constructs an ExtractionError object from an existing ExtractionError object.
 *
 * @param ee An ExtractionError object.
 */
ExtractionError::ExtractionError(const ExtractionError& ee) throw()
  : m_message(ee.m_message)
{
}

/**
 * Destroys a ExtractionError object.
 */
ExtractionError::~ExtractionError() throw()
{
}

/**
 * Gets the debugging information from a file.
 *
 * @param filename A name of the file.
 * @return An object containing the debugging information.
 */
DebugInfo* DIE_GetDebugInfo(std::string filename)
{
#ifdef TARGET_LINUX
  return DwarfDebugInfoExtractor::Get()->getDebugInfo(filename);
#else
  return NULL;
#endif
}

/** End of file die.cpp **/
